# Copyright © 2024 AgPowered Services
import copy
from typing import Any

from tutorial.util.request_meta import RequestMeta


def create_farm(request_meta: RequestMeta, party_id: str, farm_id: str, body: dict[str, Any]) -> dict[str, Any]:
    """Create a farm.

    Arguments:
    party_id -- The party_id to associate with the farm
    farm_id -- farm_id of the farm as a string
    body -- The name, description, etc. of the farm.
    """
    url = f'{request_meta.base_url}/parties/{party_id}/farms/{farm_id}'
    headers_copy = copy.deepcopy(request_meta.headers)
    headers_copy['Content-Type'] = 'application/merge-patch+json'
    params = {'api-version': request_meta.fb_api_version}

    response = request_meta.session.patch(url, headers=headers_copy, params=params, json=body)
    response.raise_for_status()
    return response.json()


def get_farm(request_meta: RequestMeta, party_id: str, farm_id: str) -> dict[str, Any]:
    """Retrieves a farm.

    Arguments:
    party_id -- UUID of the party as a string
    farm_id -- UUID of the farm as a string
    """
    url = f'{request_meta.base_url}/parties/{party_id}/farms/{farm_id}'
    params = {'api-version': request_meta.fb_api_version}

    response = request_meta.session.get(url, headers=request_meta.headers, params=params)
    response.raise_for_status()
    return response.json()
