# Copyright © 2024 AgPowered Services
import copy
from typing import Any

from tutorial.util.request_meta import RequestMeta


def create_field(request_meta: RequestMeta, party_id: str, field_id: str, body: dict[str, Any]) -> dict[str, Any]:
    """Create a field.

    Arguments:
    party_id -- The party_id to associate with the field
    field_id -- The field_id
    body -- The name, description, etc. of the farm.
    """
    url = f'{request_meta.base_url}/parties/{party_id}/fields/{field_id}'
    headers_copy = copy.deepcopy(request_meta.headers)
    headers_copy['Content-Type'] = 'application/merge-patch+json'
    params = {'api-version': request_meta.fb_api_version}

    response = request_meta.session.patch(url, headers=headers_copy, params=params, json=body)
    response.raise_for_status()
    return response.json()


def get_field(request_meta: RequestMeta, party_id: str, field_id: str) -> dict[str, Any]:
    """Retrieves a field.

    Arguments:
    party_id -- The party_id associated with the field
    field_id -- The field_id
    """
    url = f'{request_meta.base_url}/parties/{party_id}/fields/{field_id}'
    params = {'api-version': request_meta.fb_api_version}

    response = request_meta.session.get(url, headers=request_meta.headers, params=params)
    response.raise_for_status()
    return response.json()
