# Copyright © 2024 AgPowered Services
from typing import Any

from tutorial.util.request_meta import RequestMeta


def _get_jwt(request_meta: RequestMeta, tenant_id: str, client_id: str, client_secret: str, scope: str) -> str:
    """Retrieves an ADMA JWT.

    Arguments:
    tenant_id -- The tenant Id
    client_id -- The ADMA client Id
    client_secret -- The ADMA client secret
    scope -- scope of the requested JWT as a string
    """
    url = f'https://login.microsoftonline.com/{tenant_id}/oauth2/v2.0/token'
    headers = {'Content-Type': 'application/x-www-form-urlencoded'}
    params = {
        'client_id': client_id,
        'client_secret': client_secret,
        'grant_type': 'client_credentials',
        'scope': scope,
    }

    response = request_meta.session.post(url, headers=headers, data=params)
    response.raise_for_status()
    return response.json()['access_token']


def get_jwt(request_meta: RequestMeta, config: dict[str, Any]) -> str:
    return _get_jwt(request_meta, config['tenant_id'], config['client_id'], config['client_secret'], config['scope'])
