# Copyright © 2024 AgPowered Services
from typing import Any

from tutorial.util.request_meta import RequestMeta


def request(request_meta: RequestMeta, action: str, solution_id: str, body: dict[str, Any]) -> dict[str, Any]:
    """Performs a request.
    Arguments:
    solution_id -- the solution to execute against
    body -- JSON of the request
    """
    url = f'{request_meta.base_url}/solutions/{solution_id}:{action}'
    params = {'api-version': request_meta.fb_api_version}

    response = request_meta.session.post(url, headers=request_meta.headers, params=params, json=body)
    response.raise_for_status()
    return response.json()


def get_request_status(request_meta: RequestMeta, solution_id: str, body: dict[str, Any]) -> dict[str, Any]:
    """Retrieve the status of a request.
    """
    return request(request_meta, 'fetch', solution_id, body)


def submit_request(request_meta: RequestMeta, solution_id: str, body: dict[str, Any]) -> dict[str, Any]:
    """Submits a request.
    """
    return request(request_meta, 'create', solution_id, body)
