# Copyright © 2024 AgPowered Services
import json
import uuid
import yaml

from tutorial.adma import farm
from tutorial.adma.jwt import get_jwt
from tutorial.util.headers import create_bearer_token_header
from tutorial.util.request_meta import RequestMeta


def main():
    party_id = 'REPLACE_ME'  # party_id used in create_party
    farm_id = str(uuid.uuid4())
    farm_name = 'Example'
    farm_description = 'My Example Farm'

    with open('./resource/application_config.yml') as config_file:
        config = yaml.safe_load(config_file)

    jwt = get_jwt(RequestMeta(), config)
    request_meta = RequestMeta.with_config(config, create_bearer_token_header(jwt))

    body = {
        'name': farm_name,
        'description': farm_description
    }
    farm_json = farm.create_farm(request_meta, party_id, farm_id, body)
    print(json.dumps(farm_json, indent=2))


if __name__ == '__main__':
    main()
