# Copyright © 2024 AgPowered Services
import json
import uuid
import yaml

from tutorial.adma import field
from tutorial.adma.jwt import get_jwt
from tutorial.util.headers import create_bearer_token_header
from tutorial.util.request_meta import RequestMeta


def main():
    party_id = 'REPLACE_ME'  # party_id used in create_party
    farm_id = 'REPLACE_ME'   # farm_id used in create_farm
    field_id = str(uuid.uuid4())
    with open('./resource/application_config.yml') as config_file:
        config = yaml.safe_load(config_file)

    with open('./resource/el.geojson') as geojson_file:
        field_geojson = json.load(geojson_file)

    request_meta = RequestMeta()
    jwt = get_jwt(RequestMeta(), config)
    request_meta = RequestMeta.with_config(config, create_bearer_token_header(jwt))

    body = {'farmId': farm_id,
            'geometry': field_geojson['features'][0]['geometry'],
            'name': field_geojson['features'][0]['properties']['name'],
            'description': field_geojson['features'][0]['properties']['description']}

    field_json = field.create_field(request_meta, party_id, field_id, body)
    print(json.dumps(field_json, indent=2))


if __name__ == '__main__':
    main()
