# Copyright © 2024 AgPowered Services
import json
import uuid
import yaml

from tutorial.adma import party
from tutorial.adma.jwt import get_jwt
from tutorial.util.headers import create_bearer_token_header
from tutorial.util.request_meta import RequestMeta


def main():
    party_id = str(uuid.uuid4())
    party_name = 'Example'
    party_description = 'My Example Party'
    with open('./resource/application_config.yml') as config_file:
        config = yaml.safe_load(config_file)

    jwt = get_jwt(RequestMeta(), config)
    request_meta = RequestMeta.with_config(config, create_bearer_token_header(jwt))

    body = {
        'name': party_name,
        'description': party_description
    }
    party_json = party.create_party(request_meta, party_id, body)
    print(json.dumps(party_json, indent=2))


if __name__ == '__main__':
    main()