import jsonformatter
import logging
import logging.config
from atexit import register
from datetime import datetime, timezone
from logging.config import ConvertingList
from logging.handlers import QueueHandler, QueueListener
from queue import Queue

# from contextvars import ContextVar
# from uuid import uuid4

from jsonformatter.jsonformatter import BASIC_FORMAT

# request_id = ContextVar('Id of the request', default=str(uuid4()))
# caller_id = ContextVar('Id of the caller', default='adma')


# class ContextVarInjectionFilter(logging.Filter):
#     """
#     Modifies logging records by attaching a request_id and caller_id
#     """
#
#     def filter(self, record):
#         record.requestId = request_id.get()
#         record.callerId = caller_id.get()
#         return True


class CommonApiFilter(logging.Filter):
    """
    Filters out common API messages
    """
    def filter(self, record):
        message = record.getMessage()
        return "/healthz" not in message and "/openapi.json" not in message


def _resolve_handlers(l):
    result = l
    if isinstance(l, ConvertingList):
        result = [l[i] for i in range(len(l))]

    return result


# Setup asynchronous logging
class QueueListenerHandler(QueueHandler):
    def __init__(self, handlers=None, max_size=-1, respect_handler_level=True):
        super().__init__(Queue(max_size))
        resolved_handlers = _resolve_handlers(handlers)
        self.listener = QueueListener(self.queue,*resolved_handlers,
                                      respect_handler_level=respect_handler_level)
        self.start()
        register(self.stop)

    def start(self):
        self.listener.start()

    def stop(self):
        self.listener.stop()

    def emit(self, record):
        return super().emit(record)


class ContextVarJsonFormatter(jsonformatter.JsonFormatter):
    def __init__(self, fmt=BASIC_FORMAT, datefmt=None, style='%', record_custom_attrs=None, mix_extra=False,
                 mix_extra_position='tail', skipkeys=False, ensure_ascii=True, check_circular=True, allow_nan=True,
                 cls=None, indent=None, separators=None, encoding='utf-8', default=None, sort_keys=False, **kw):
        super().__init__(fmt, datefmt, style, record_custom_attrs, mix_extra, mix_extra_position, skipkeys,
                         ensure_ascii, check_circular, allow_nan, cls, indent, separators, encoding, default, sort_keys,
                         **kw)
        # self.record_custom_attrs = {
        #     'request_id': lambda **record: request_id.get(),
        #     'caller_id': lambda **record: caller_id.get(),
        # }


def configure_logging(logging_config):
    # Formats the date and time in ISO 8601 format in the UTC timezone
    logging.Formatter.formatTime = (lambda self, record, datefmt=None:
                                    datetime.utcfromtimestamp(record.created)
                                    .astimezone(tz=timezone.utc)
                                    .isoformat(sep="T", timespec="milliseconds"))
    # Configure logging
    logging.config.dictConfig(config=logging_config)
