# Copyright © 2024 AgPowered Services
from dataclasses import dataclass, field
from typing import Any

from requests import Session
from requests.adapters import HTTPAdapter, Retry

import requests


def default_session() -> Session:
    retry = Retry(
        total=5,
        backoff_factor=1,
        status_forcelist=[429, 502, 503, 504]
    )
    http_adapter = HTTPAdapter(max_retries=retry)
    session = requests.Session()
    session.mount("https://", http_adapter)
    session.mount("http://", http_adapter)
    return session


@dataclass
class RequestMeta:
    base_url: str = field(default=None)
    fb_api_version: str = field(default=None)
    headers: dict[str, Any] = field(default=None)
    session: Session = field(default=default_session())


    @classmethod
    def with_config(cls, config: dict[str, Any], headers: dict[str, Any]):
        return cls(config['base_url'], config['fb_api_version'], headers)
